@@ -1,7 +1,7 @@
 package Data::Transmute;
 
-our $DATE = '2019-08-23'; # DATE
-our $VERSION = '0.035'; # VERSION
+our $DATE = '2019-10-10'; # DATE
+our $VERSION = '0.036'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -68,6 +68,50 @@ sub _rulereverse_rename_hash_key {
     }];
 }
 
+sub _rule_modify_hash_value {
+    require Data::Cmp;
+
+    my %args = @_;
+
+    my $data = $args{data};
+    return unless ref $data eq 'HASH';
+    my $name = $args{name};
+    die "Rule modify_hash_value: Please specify 'name' (key)" unless defined $name;
+    my $from = $args{from};
+    my $from_exists = exists $args{from};
+    my $to   = $args{to};
+    die "Rule rename_hash_key: Please specify 'to'" unless exists $args{to};
+
+    my $errprefix = "Rule modify_hash_value: Can't modify key '$name'".
+        ($from_exists ? " from '".($from // '<undef>') : "").
+        "' to '".($to // '<undef>')."'";
+
+    unless (exists $data->{$name}) {
+        die "$errprefix: key does not exist";
+    }
+
+    my $cur = $data->{$name};
+
+    if ($from_exists) {
+        # noop
+        return unless Data::Cmp::cmp_data($from, $to);
+
+        if (Data::Cmp::cmp_data($cur, $from)) {
+            die "$errprefix: current value is not '".($cur // '<undef>')."'";
+        }
+    }
+
+    $data->{$name} = $to;
+}
+
+sub _rulereverse_modify_hash_value {
+    my %args = @_;
+    die "Cannot generate reverse rule modify_hash_value without from" unless exists $args{from};
+    [modify_hash_value => {
+        name => $args{name}, from => $args{to}, to => $args{from},
+    }];
+}
+
 sub _rule_delete_hash_key {
     my %args = @_;
 
@@ -252,7 +296,7 @@ Data::Transmute - Transmute (transform) data structure using rules data
 
 =head1 VERSION
 
-This document describes version 0.035 of Data::Transmute (from Perl distribution Data-Transmute), released on 2019-08-23.
+This document describes version 0.036 of Data::Transmute (from Perl distribution Data-Transmute), released on 2019-10-10.
 
 =head1 SYNOPSIS
 
@@ -412,6 +456,30 @@ exists.
 
 =back
 
+=head2 modify_hash_value
+
+This rule only applies when data is a hash, when data is not a hash this will do
+nothing. Modify a single hash value from original value I<from> to new value
+I<to>. Key must exist, and value must originally be I<from>.
+
+Known arguments (C<*> means required):
+
+=over
+
+=item * name*
+
+String. Key name.
+
+=item * from*
+
+String or undef. Original value.
+
+=item * to*
+
+String or undef. New value.
+
+=back
+
 =head2 delete_hash_key
 
 This rule only applies when data is a hash, when data is not a hash this will do
@@ -622,6 +690,8 @@ L<Config::Model>, which you can also use to convert/upgrade configuration files.
 But I find this module slightly too heavyweight for the simpler needs that I
 have, hence I created Data::Transmute.
 
+L<Bencher::Scenarios::DataTransmute>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
